@@ -8,6 +8,13 @@ from preseem.preseem_model import BaseModelObject
 from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 
+def has_any_fields_set(message):
+    for field_desc, value in message.ListFields():
+        if value:
+            return True
+    return False
+
+
 class FakePreseemModel:
     _companies = {}  # company_uuid to Company object
     _elements = {}  # company_uuid to {element_uuid to Element object}
@@ -418,7 +425,7 @@ class FakePreseemModel:
                       package_uuid=kwargs.get('package_uuid'),
                       download_rate=kwargs.get('download_rate'),
                       upload_rate=kwargs.get('upload_rate'),
-                      attachment=attachment,
+                      attachment=attachment if has_any_fields_set(attachment) else None,
                       subscriber_identifier=kwargs.get('subscriber_identifier'))
             services = FakePreseemModel._services.get(company.uuid)
             if services is None:
@@ -458,12 +465,14 @@ class FakePreseemModel:
                         if val:
                             assert isinstance(val, SetAttachmentReq)
                             attr = 'attachment'
-                            val = val.attachment
+                            if has_any_fields_set(val.attachment):
+                                val = val.attachment
+                            else:
+                                val = None
                     if attr == 'company_uuid' or attr == 'uuid':
                         continue
                     elif attr == 'inactive' and val is True:
                         FakePreseemModel._set_inactive(service)
                     else:
-                        if getattr(service, attr) != val:
-                            service.updated_at = time.time()
+                        service.updated_at = time.time()
                         setattr(service, attr, val)
