@@ -110,6 +110,9 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                             for sf in bval.DESCRIPTOR.fields:
                                 smval = getattr(mval, sf.name)
                                 sbval = getattr(bval, sf.name)
+                                if sf.name == 'mac_addresses':
+                                    smval = set(x for x in smval)
+                                    sbval = set(x for x in sbval)
                                 if sf.name == 'network_prefixes':
                                     smval = set([ip_network(x) for x in smval])
                                     sbval = set([ip_network(x) for x in sbval])
