@@ -1205,6 +1205,34 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(msvc.updated_at, model_services[0].updated_at)
         self._await(test())
 
+    def test_service_mac_order(self):
+        """The order of MAC addresses doesn't matter."""
+        async def test():
+            # create a service
+            service = Service('service01')
+            services = {'service01': service}
+            service.attachment.mac_addresses.append('00:01:02:03:04:05')
+            service.attachment.mac_addresses.append('06:07:08:09:0a:0b')
+
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
+            await self.checkSourceService(service)
+
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            msvc = model_services[0]
+
+            service = Service('service01')
+            services = {'service01': service}
+            service.attachment.mac_addresses.append('06:07:08:09:0a:0b')
+            service.attachment.mac_addresses.append('00:01:02:03:04:05')
+
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
+            with self.assertRaises(AssertionError):
+                await self.checkSourceService(service)  # will fail due to order
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            # check that we did not actually do an update
+            self.assertEqual(msvc.updated_at, model_services[0].updated_at)
+        self._await(test())
+
     async def checkSourceRouter(self, sobj):
         sites = {}
         for site in await self.model.Site.List(company_uuid=self.company.uuid):
